@@ -1,25 +1,29 @@
-import os
 import json
+import os
+
 import yaml
+
+from . import parser  # noqa
 from .errors import OpenmanException
-import parser
-from .schema_converter import SchemaConvertor
+from .schema_converter import SchemaConvertor  # noqa
+
 
 def from_collection(postmanfile=None):
     if postmanfile is None:
-        raise OpenmanException('Empty file is not allowed')
+        raise OpenmanException("Empty file is not allowed")
     if not os.path.isfile(postmanfile):
         raise FileNotFoundError("Postman collection not found")
-    with open(postmanfile, 'r') as f:
+    with open(postmanfile, "r") as f:
         return json.load(f)
 
+
 def from_ignore(ignorefile=None):
     ignoreschema = {}
     if not ignorefile:
         return ignoreschema
-    with open(ignorefile, 'r') as f:
+    with open(ignorefile, "r") as f:
         try:
             ignoreschema = yaml.safe_load(f)
-        except yaml.YAMLError as exc:
+        except yaml.YAMLError:
             ignoreschema = json.load(f)
-    return ignoreschema
\ No newline at end of file
+    return ignoreschema
